@@ -30,6 +30,7 @@ proxies = {
 # Variables - Nexus
 nexus_format = ''
 artifact_name = ''
+artifact_name2 = ''
 work_directory = ''
 repository_name = ''
 nexus_format = ''
@@ -100,6 +101,7 @@ def main(argv):
     # Variables - Nexus
     global nexus_format 
     global artifact_name
+    global artifact_name2
     global work_directory
     global repository_name
     global nexus_format
@@ -273,6 +275,11 @@ def main(argv):
         elif opt == '--file2':
             if action == 'deltav':
                 version_file2 = arg 
+            if action == 'nexus':
+                artifact_name2 = arg
+                if artifact_name2 == '':
+                    print("Please specify second artifact name")
+                    return sys.exit(2)
             else:
                 print("Invalid command specified: param: --file2")   
         ## Deploy-artifact-awx-host params START
