@@ -37,7 +37,12 @@ def extract():
                         if commands.get('branch'):
                             __main__.branch = commands.get('branch')
                             print("INFO: Branch specified: ", __main__.branch)
-                        
+                        if commands.get('file'):
+                            __main__.version_file1 = commands.get('file')
+                            
+                        if commands.get('file2'):
+                            __main__.version_file2 = commands.get('file2')
+                            
                         # Fetch pre release value
                         if commands.get('preValue'):
                             __main__.pre_value = commands.get('preValue')
