@@ -85,9 +85,9 @@ def create_sonarq_project(name, projectkey):
         
         if __main__.language.lower() == 'java' and __main__.arch_type.lower() == 'gradle':
             print("Declare org.sonarqube plugin in build.gradle file\n")
-            print("plugins {\n   id \"org.sonarqube\" version \"2.7\"\n}\n")
+            print("plugins {\n   id \"org.sonarqube\" version \"3.0\"\n}\n")
             
-            print("Windows command below:\n gradlew sonarqube -Dsonar.projectKey={} -Dsonar.host.url={} -Dsonar.login={}".format(projectkey, __main__.sonarhost, token_value))
+            print("Windows command below:\n gradlew.bat sonarqube -Dsonar.projectKey={} -Dsonar.host.url={} -Dsonar.login={}".format(projectkey, __main__.sonarhost, token_value))
             print("\nLinux command below:\n gradle sonarqube -Dsonar.projectKey={} -Dsonar.host.url={} -Dsonar.login={}".format(projectkey, __main__.sonarhost, token_value))
             
         elif __main__.language.lower() in ['c#', 'vb.net']:
